@@ -18,7 +18,7 @@ role DBIx::NamedQueries::Write is DBIx::NamedQueries::Query {
     method update( %params ) { ... }
 }
 
-class DBIx::NamedQueries:ver<0.0.2>:auth<cpan:MZIESCHA> { 
+class DBIx::NamedQueries:ver<0.0.3>:auth<cpan:MZIESCHA> { 
 
     has Str   $.divider = '/';
     has Str   $.namespace;
@@ -190,7 +190,7 @@ documentation
 
 =head1 SEE ALSO
 
-L<<https://github.com/perl6/DBIish>>
+L<<https://gitlab.com/perl6/DBIish>>
 
 =head1 AUTHOR
 
