@@ -3,7 +3,7 @@ use v6.c;
 use DBIish;
 use DBIx::NamedQueries::Handles;
 
-class DBIx::NamedQueries::Handle::DBIish:ver<0.0.2> does DBIx::NamedQueries::Handle {
+class DBIx::NamedQueries::Handle::DBIish:ver<0.0.3> does DBIx::NamedQueries::Handle {
 
     multi method connect( Str:D $driver, Str:D $database ) {
         return DBIish.connect( $driver, :database( $database ) );
@@ -86,7 +86,7 @@ documentation
 
 =head1 SEE ALSO
 
-L<<https://github.com/perl6/DBIish>>
+L<<https://gitlab.com/perl6/DBIish>>
 
 =head1 AUTHOR
 
