@@ -14,7 +14,7 @@ role DBIx::NamedQueries::Handle {
     multi method connect( Str:D $driver, Str:D $database ) {...}
 }
 
-class DBIx::NamedQueries::Handles:ver<0.0.2> {
+class DBIx::NamedQueries::Handles:ver<0.0.3> {
     has Array $!read_only = [];
     has Array $!read_write = [];
     
@@ -124,7 +124,7 @@ documentation
 
 =head1 SEE ALSO
 
-L<<https://github.com/perl6/DBIish>>
+L<<https://gitlab.com/perl6/DBIish>>
 
 =head1 AUTHOR
 
